fedex.services.track_service

Package fedex :: Package services :: Module track_service |
[hide private]
[frames] | no frames]

# Module track_service

source code

# Tracking Service Module

This package contains the shipment tracking methods defined by Fedex's TrackService WSDL file. Each is encapsulated in a class for easy access. For more details on each, refer to the respective class's documentation.

Classes | [hide private]
| FedexInvalidTrackingNumber Exception: Sent when a bad tracking number is provided.
| FedexTrackRequest This class allows you to track shipments by providing a tracking number or other identifying features.

Variables | [hide private]
| __package__ = ``'``fedex.services``'``